sr7-arrow,sr7-arrwrap,sr7-bullet,sr7-bullets,sr7-nav-img,sr7-navmask,sr7-tab,sr7-tabs,sr7-tabs-wrap,sr7-thumb,sr7-thumbs,sr7-thumbs-wrap{display:block;pointer-events:all}sr7-tab{overflow:hidden}sr7-nav-img canvas{width:100%;height:100%}.sr7-arrows{cursor:pointer;background:#000;background:rgba(0,0,0,.5);width:40px;height:40px;position:absolute;display:block;z-index:1000}.sr7-arrows.sr7-touchhover{background:#000}.sr7-arrows:before{font-family:revicons;font-size:15px;color:#fff;display:block;line-height:40px;text-align:center}.sr7-arrows.sr7-leftarrow:before{content:'\e824'}.sr7-arrows.sr7-rightarrow:before{content:'\e825'}.sr7-bullets,.sr7-tabs,.sr7-thumbs{position:absolute;display:block;z-index:1000;top:0;left:0}.sr7-tabs,.sr7-thumbs{box-sizing:content-box!important}.sr7-bullet{width:15px;height:15px;position:absolute;background:#fff;background:rgba(255,255,255,.3);cursor:pointer}.sr7-bullet.selected,.sr7-bullet.sr7-touchhover{background:#fff}sr7-tabs-wrap,sr7-thumbs-wrap{position:relative;width:100%;height:100%}.sr7-tab.selected,.sr7-tab.sr7-touchhover,.sr7-thumb.selected,.sr7-thumb.sr7-touchhover{opacity:1}.sr7-tab,.sr7-thumb{cursor:pointer;position:absolute;opacity:.5;box-sizing:border-box}sr7-tt-mask{display:block;position:absolute;overflow:hidden;box-sizing:border-box}.sr7-tab-img,.sr7-thumb-img{background-position:center center;background-size:cover;width:100%;height:100%;display:block;position:absolute;top:0;left:0}sr7-navdc{all:unset;display:inline}sr7-nav-img-live,sr7-nav-img-tmp{display:block;position:absolute;top:0;left:0;width:100%;height:100%}sr7-scrubber{position:absolute;display:block;z-index:1000;top:0;left:0;box-sizing:content-box!important;contain:size}sr7-scrubber-wrap{display:block;top:0;left:0}sr7-scrubber-handle{display:block;background-color:#faebd7;width:20px;height:20px;position:relative!important}sr7-scrubber-progress{display:block;position:absolute;width:100%;height:100%;background-color:rgba(0,0,0,.5)}sr7-scrubber .sr7-scrubber-img{background-position:center center;background-size:cover;width:100%;height:100%;display:block;position:absolute;top:0;left:0}.sr7-scrubber-hra,.sr7-scrubber-ra{right:0}.sr7-scrubber-hla,.sr7-scrubber-la{left:0}.sr7-scrubber-a,.sr7-scrubber-ha{display:block;position:absolute;min-height:100%;display:flex;justify-content:center;align-items:center}