sr7-prl.prlt9 {
	width: 40px;
	height: 40px;
	-webkit-transform: translate(-50%, -50%);
	transform: translate(-50%, -50%)
}

sr7-prl.prlt9 .sr7-prl-inner span {
	display: block;
	width: 100%;
	height: 100%;
	border-radius: 50%;
	opacity: .6;
	position: absolute;
	top: 0;
	left: 0;
	-webkit-animation: rs-revealer-9 2s infinite ease-in-out;
	animation: rs-revealer-9 2s infinite ease-in-out
}

sr7-prl.prlt9 .sr7-prl-inner span:last-child {
	-webkit-animation-delay: -1s;
	animation-delay: -1s
}

@-webkit-keyframes rs-revealer-9 {

	0%,
	100% {
		-webkit-transform: scale(0)
	}

	50% {
		-webkit-transform: scale(1)
	}
}

@keyframes rs-revealer-9 {

	0%,
	100% {
		transform: scale(0);
		-webkit-transform: scale(0)
	}

	50% {
		transform: scale(1);
		-webkit-transform: scale(1)
	}
}