.sr7-layer .sr7-media,.sr7-layer .sr7-poster{top:0;left:0;width:100%;height:100%;position:absolute;display:block;z-index:1;line-height:0}.sr7-layer .sr7-media{z-index:2}.sr7-layer.nointeraction .sr7-media,.sr7-layer.nointeraction .sr7-media *,.sr7-layer.nointeraction .sr7-poster{pointer-events:none!important}sr7-media,sr7-media *,sr7-poster{-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}sr7-media .sr7-html5-video{top:0;left:0;position:relative;z-index:5;margin:0;outline:0;padding:0}sr7-media iframe{opacity:0;width:100;height:100%}sr7-lrg-ctrl{opacity:0;transition:opacity .5s ease-in-out;position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);width:50px;height:50px;border-radius:6px;background-color:rgba(0,0,0,.6);cursor:pointer;display:flex;justify-content:center;align-items:center;z-index:10}sr7-lrg-ctrl.paused sr7-lrg-pause,sr7-lrg-ctrl.playing sr7-lrg-play{display:block;opacity:1;transition:opacity .2s ease-in-out}sr7-lrg-ctrl.paused sr7-lrg-play,sr7-lrg-ctrl.playing sr7-lrg-pause{display:block;opacity:0;transition:opacity .2s ease-in-out}.sr7-layer:hover sr7-lrg-ctrl{opacity:1}sr7-lrg-pause,sr7-lrg-play{position:absolute;width:20px;height:20px;display:none;opacity:0}sr7-lrg-play:before{content:'';position:absolute;top:0;left:2px;border-style:solid;border-width:10px 0 10px 20px;border-color:transparent transparent transparent #fff}sr7-lrg-pause:after,sr7-lrg-pause:before{content:'';position:absolute;top:0;width:6px;height:20px;background-color:#fff}sr7-lrg-pause:before{left:2px}sr7-lrg-pause:after{right:2px}.sr7-hidden-audio,.sr7-hidden-audio *{visibility:hidden!important;pointer-events:none!important}.sr7-layer.sr7_miah sr7-media{position:relative}