sr7-prl.prlt8 {
	width: 50px;
	height: 50px;
	-webkit-transform: translate(-50%, -50%);
	transform: translate(-50%, -50%)
}

sr7-prl.prlt8 .sr7-prl-inner {
	width: 100%;
	height: 100%;
	display: inline-block;
	padding: 0;
	text-align: left
}

sr7-prl.prlt8 .sr7-prl-inner span {
	position: absolute;
	display: inline-block;
	width: 100%;
	height: 100%;
	border-radius: 100%;
	-webkit-animation: rs-revealer-8 1.6s linear infinite;
	animation: rs-revealer-8 1.6s linear infinite
}

sr7-prl.prlt8 .sr7-prl-inner span:last-child {
	animation-delay: -.8s;
	-webkit-animation-delay: -.8s
}

@keyframes rs-revealer-8 {
	0% {
		transform: scale(0, 0);
		opacity: .5
	}

	100% {
		transform: scale(1, 1);
		opacity: 0
	}
}

@-webkit-keyframes rs-revealer-8 {
	0% {
		-webkit-transform: scale(0, 0);
		opacity: .5
	}

	100% {
		-webkit-transform: scale(1, 1);
		opacity: 0
	}
}