sr7-prl.prlt13 {
	width: 40px;
	height: 40px;
	-webkit-transform: translate(-50%, -50%);
	transform: translate(-50%, -50%)
}

sr7-prl.prlt13 .sr7-prl-inner {
	width: 100%;
	height: 100%
}

sr7-prl.prlt13 .sr7-prl-inner span {
	display: block;
	width: 40%;
	height: 40%;
	position: absolute;
	border-radius: 50%;
	-webkit-animation: rs-revealer-13 2s ease infinite;
	animation: rs-revealer-13 2s ease infinite
}

sr7-prl.prlt13 .sr7-prl-inner span:nth-child(1) {
	animation-delay: -1.5s;
	-webkit-animation-delay: -1.5s
}

sr7-prl.prlt13 .sr7-prl-inner span:nth-child(2) {
	animation-delay: -1s;
	-webkit-animation-delay: -1s
}

sr7-prl.prlt13 .sr7-prl-inner span:nth-child(3) {
	animation-delay: -.5s;
	-webkit-animation-delay: -.5s
}

@keyframes rs-revealer-13 {

	0%,
	100% {
		transform: translate(0)
	}

	25% {
		transform: translate(160%)
	}

	50% {
		transform: translate(160%, 160%)
	}

	75% {
		transform: translate(0, 160%)
	}
}

@-webkit-keyframes rs-revealer-13 {

	0%,
	100% {
		-webkit-transform: translate(0)
	}

	25% {
		-webkit-transform: translate(160%)
	}

	50% {
		-webkit-transform: translate(160%, 160%)
	}

	75% {
		-webkit-transform: translate(0, 160%)
	}
}