sr7-prl.prlt7 {
	width: 35px;
	height: 35px;
	-webkit-transform: translate(-50%, -50%);
	transform: translate(-50%, -50%)
}

sr7-prl.prlt7 .sr7-prl-inner {
	width: 100%;
	height: 100%;
	display: inline-block;
	padding: 0;
	border-radius: 100%;
	border: 2px solid;
	-webkit-animation: rs-revealer-7 .8s linear infinite;
	animation: rs-revealer-7 .8s linear infinite
}

@keyframes rs-revealer-7 {
	from {
		transform: rotate(0)
	}

	to {
		transform: rotate(360deg)
	}
}

@-webkit-keyframes rs-revealer-7 {
	from {
		-webkit-transform: rotate(0)
	}

	to {
		-webkit-transform: rotate(360deg)
	}
}