sr7-prl.prlt4 {
	margin: -20px 0px 0px -20px;
	width: 40px;
	height: 40px;
	text-align: center;
	animation: tp-rotate 2.0s infinite linear;
}

sr7-prl.prlt4 .dot1,
sr7-prl.prlt4 .dot2 {
	width: 60%;
	height: 60%;
	display: inline-block;
	position: absolute;
	top: 0;
	background-color: #fff;
	border-radius: 100%;
	animation: tp-bounce 2.0s infinite ease-in-out;
	box-shadow: 0px 0px 20px 0px rgba(0,0,0,0.15);
}

sr7-prl.prlt4 .dot2 {
	top: auto;
	bottom: 0px;
	animation-delay: -1.0s;
}

@keyframes tp-bounce {
	0%, 100% {transform: scale(0.0);}
	50% { transform: scale(1.0);}
}