sr7-prl.prlt5 	{
	background-image:url(./loader.gif);
	background-repeat:no-repeat;
	background-position:10px 10px;
	background-color:#fff;
	margin:-22px -22px;
	width:44px;height:44px;
	border-radius: 3px;
}