sr7-prl.prlt15 {
	width: 40px;
	height: 40px;
	margin-top: -4px;
	-webkit-transform: translate(-50%, -50%);
	transform: translate(-50%, -50%)
}

sr7-prl.prlt15 .sr7-prl-inner {
	width: 100%;
	height: 100%
}

sr7-prl.prlt15 .sr7-prl-inner span {
	display: block;
	width: 20px;
	height: 20px;
	position: absolute;
	top: 0;
	left: 0;
	-webkit-animation: rs-revealer-15 1.8s infinite ease-in-out;
	animation: rs-revealer-15 1.8s infinite ease-in-out
}

sr7-prl.prlt15 .sr7-prl-inner:last-child {
	-webkit-animation-delay: -.9s;
	animation-delay: -.9s
}

@-webkit-keyframes rs-revealer-15 {
	25% {
		-webkit-transform: translateX(30px) rotate(-90deg) scale(.5)
	}

	50% {
		-webkit-transform: translateX(30px) translateY(30px) rotate(-180deg)
	}

	75% {
		-webkit-transform: translateX(0) translateY(30px) rotate(-270deg) scale(.5)
	}

	100% {
		-webkit-transform: rotate(-360deg)
	}
}

@keyframes rs-revealer-15 {
	25% {
		transform: translateX(30px) rotate(-90deg) scale(.5);
		-webkit-transform: translateX(30px) rotate(-90deg) scale(.5)
	}

	50% {
		transform: translateX(30px) translateY(30px) rotate(-179deg);
		-webkit-transform: translateX(30px) translateY(30px) rotate(-179deg)
	}

	50.1% {
		transform: translateX(30px) translateY(30px) rotate(-180deg);
		-webkit-transform: translateX(30px) translateY(30px) rotate(-180deg)
	}

	75% {
		transform: translateX(0) translateY(30px) rotate(-270deg) scale(.5);
		-webkit-transform: translateX(0) translateY(30px) rotate(-270deg) scale(.5)
	}

	100% {
		transform: rotate(-360deg);
		-webkit-transform: rotate(-360deg)
	}
}