sr7-loop,sr7-mask,sr7-module,sr7-module sr7-img,sr7-module sr7-shp,sr7-module sr7-svg,sr7-moudule .sr7-layer,sr7-moudule sr7-layer,sr7-px{user-select:none}.sr7-staticslide{pointer-events:none}sr7-loop,sr7-px{visibility:hidden;display:none;overflow:visible}sr7-col>sr7-px{visibility:inherit;display:block}sr7-px>sr7-loop{visibility:inherit;display:block}sr7-row>sr7-px>sr7-loop>sr7-row-con{display:table!important}sr7-col>sr7-px>sr7-loop{z-index:1;position:relative}sr7-col>sr7-px>sr7-col-bg{z-index:0!important}sr7-mask{overflow:hidden;visibility:hidden;display:none}sr7-img{line-height:0;overflow:hidden}sr7-svg>svg{width:100%;height:100%;display:block}sr7-col>sr7-loop,sr7-col>sr7-mask,sr7-row>sr7-loop,sr7-row>sr7-mask{visibility:visible;display:block;width:100%;height:100%;position:relative;z-index:1}sr7-loop>.sr7-layer,sr7-mask>.sr7-layer{position:relative}.sr7_splitted_lines{display:block;color:inherit;font-size:inherit;font-weight:inherit;line-height:inherit}.sr7_splitted_chars,.sr7_splitted_words,.sr7_splitted_words_noanim{display:inline-block;color:inherit;font-size:inherit;font-weight:inherit;line-height:inherit}sr7-row-con{width:100%;display:table;position:relative;box-sizing:border-box}sr7-col-con{display:block;height:100%;box-sizing:border-box;z-index:1;position:relative;line-height:inherit;vertical-align:inherit}sr7-col-bg,sr7-col-bg-mask{display:block;position:absolute;z-index:0}sr7-3dwrap.sr7-3dwrap-bg,sr7-3dwrap.sr7-3dwrap-layers{position:absolute;top:0;left:0;z-index:3;transform:perspective(1600px);width:100%;height:100%;transform-origin:50% 50%;transform-style:flat}sr7-3dwrap.sr7-3dwrap-bg{z-index:1;transform:perspective(1600px)}.sr7-3dwrap-bg-no-3d{transform-style:flat;z-index:0}sr7-3dwrap.sr7-3dwrap-bg{z-index:0}.sr7-fullscreen{position:fixed!important;width:100%!important;height:100%!important;top:0!important;left:0!important;z-index:9999999!important;background:#fff}sr7-mask sr7-fxc{display:block;position:absolute;top:0;left:0;width:100%;height:100%;pointer-events:none;visibility:visible;z-index:100;transform:scaleX(0)}.sr7-fx-hidden{visibility:hidden!important}sr7-overlay{pointer-events:none}.sr7--hidden{opacity:0!important;visibility:hidden!important;transition:opacity .3s ease-out,visibility .3s ease-out}h1.sr7-layer,h2.sr7-layer,h3.sr7-layer,h4.sr7-layer,h5.sr7-layer,h6.sr7-layer{margin:0;padding:0}sr7-modals{position:fixed;top:0;left:0;width:100%;height:100%;z-index:9999;display:none;overflow:auto;overflow-x:hidden}sr7-modal-underlay{position:fixed;top:0;left:0;width:100%;height:100%;z-index:0;background-color:rgba(0,0,0,.5)}.sr7-hiddenAutoContainer{opacity:0!important}sr7-module-shadow{display:block;width:100%;height:100%;position:absolute;top:0;left:0;pointer-events:none;z-index:-1}.sr7-shdw-1{box-shadow:0 10px 6px -6px rgba(0,0,0,.8)}.sr7-shdw-5{position:relative;box-shadow:0 1px 4px rgba(0,0,0,.3),0 0 40px rgba(0,0,0,.1) inset}.sr7-shdw-2:after,.sr7-shdw-2:before,.sr7-shdw-3:before,.sr7-shdw-4:after{z-index:-2;position:absolute;content:"";bottom:10px;left:10px;width:50%;top:85%;max-width:300px;background:0 0;box-shadow:0 15px 10px rgba(0,0,0,.8);transform:rotate(-3deg)}.sr7-shdw-2:after,.sr7-shdw-4:after{transform:rotate(3deg);right:10px;left:auto}.sr7-shdw-5:after{width:100%;height:100%;top:0;left:0;content:"";background:#fff;z-index:0;position:absolute}.sr7-shdw-5:before{content:"";position:absolute;z-index:-2;box-shadow:0 0 25px 0 rgba(0,0,0,.6);top:30%;bottom:0;left:20px;right:20px;border-radius:100px/20px}.sr7-layer .sr-starring{display:inline-block}.sr7-layer .sr-starring .star-rating{float:none;display:inline-block;vertical-align:top;color:#ffc321!important}.sr7-layer .sr-starring .star-rating,.sr7-layer .sr-starring-page .star-rating{position:relative;height:1em;width:5.4em;font-family:star;font-size:1em!important}.sr7-layer .sr-starring .star-rating:before,.sr7-layer .sr-starring-page .star-rating:before{content:"\73\73\73\73\73";color:#e0dadf;float:left;top:0;left:0;position:absolute}.sr7-layer .sr-starring .star-rating span{overflow:hidden;float:left;top:0;left:0;position:absolute;padding-top:1.5em;font-size:1em!important}.sr7-layer .sr-starring .star-rating span:before{content:"\53\53\53\53\53";top:0;position:absolute;left:0}