sr7-prl.prlt11 {
	width: 39px;
	height: 39px;
	-webkit-transform: translate(-50%, -50%);
	transform: translate(-50%, -50%)
}

sr7-prl.prlt11 .sr7-prl-inner {
	width: 100%;
	height: 100%
}

sr7-prl.prlt11 .sr7-prl-inner span {
	display: block;
	width: 13px;
	height: 13px;
	background-color: #333;
	float: left;
	-webkit-animation: rs-revealer-11 1.3s infinite ease-in-out;
	animation: rs-revealer-11 1.3s infinite ease-in-out
}

sr7-prl.prlt11 .sr7-prl-inner span:nth-child(1) {
	-webkit-animation-delay: .2s;
	animation-delay: .2s
}

sr7-prl.prlt11 .sr7-prl-inner span:nth-child(2) {
	-webkit-animation-delay: .3s;
	animation-delay: .3s
}

sr7-prl.prlt11 .sr7-prl-inner span:nth-child(3) {
	-webkit-animation-delay: .4s;
	animation-delay: .4s
}

sr7-prl.prlt11 .sr7-prl-inner span:nth-child(4) {
	-webkit-animation-delay: .1s;
	animation-delay: .1s
}

sr7-prl.prlt11 .sr7-prl-inner span:nth-child(5) {
	-webkit-animation-delay: .2s;
	animation-delay: .2s
}

sr7-prl.prlt11 .sr7-prl-inner span:nth-child(6) {
	-webkit-animation-delay: .3s;
	animation-delay: .3s
}

sr7-prl.prlt11 .sr7-prl-inner span:nth-child(7) {
	-webkit-animation-delay: 0s;
	animation-delay: 0s
}

sr7-prl.prlt11 .sr7-prl-inner span:nth-child(8) {
	-webkit-animation-delay: .1s;
	animation-delay: .1s
}

sr7-prl.prlt11 .sr7-prl-inner span:nth-child(9) {
	-webkit-animation-delay: .2s;
	animation-delay: .2s
}

@-webkit-keyframes rs-revealer-11 {

	0%,
	100%,
	70% {
		-webkit-transform: scale3D(1, 1, 1);
		transform: scale3D(1, 1, 1)
	}

	35% {
		-webkit-transform: scale3D(0, 0, 1);
		transform: scale3D(0, 0, 1)
	}
}

@keyframes rs-revealer-11 {

	0%,
	100%,
	70% {
		-webkit-transform: scale3D(1, 1, 1);
		transform: scale3D(1, 1, 1)
	}

	35% {
		-webkit-transform: scale3D(0, 0, 1);
		transform: scale3D(0, 0, 1)
	}
}