sr7-prl.prlt10 {
	width: 54px;
	height: 40px;
	-webkit-transform: translate(-50%, -50%);
	transform: translate(-50%, -50%)
}

sr7-prl.prlt10 .sr7-prl-inner {
	width: 100%;
	height: 100%;
	text-align: center;
	font-size: 10px
}

sr7-prl.prlt10 .sr7-prl-inner span {
	display: block;
	height: 100%;
	width: 6px;
	margin-right:1px;
	display: inline-block;
	-webkit-animation: rs-revealer-10 1.2s infinite ease-in-out;
	animation: rs-revealer-10 1.2s infinite ease-in-out
}

sr7-prl.prlt10 .sr7-prl-inner span:nth-child(2) {
	-webkit-animation-delay: -1.1s;
	animation-delay: -1.1s
}

sr7-prl.prlt10 .sr7-prl-inner span:nth-child(3) {
	-webkit-animation-delay: -1s;
	animation-delay: -1s
}

sr7-prl.prlt10 .sr7-prl-inner span:nth-child(4) {
	-webkit-animation-delay: -.9s;
	animation-delay: -.9s
}

sr7-prl.prlt10 .sr7-prl-inner span:nth-child(5) {
	-webkit-animation-delay: -.8s;
	animation-delay: -.8s
}

@-webkit-keyframes rs-revealer-10 {

	0%,
	100%,
	40% {
		-webkit-transform: scaleY(.4)
	}

	20% {
		-webkit-transform: scaleY(1)
	}
}

@keyframes rs-revealer-10 {

	0%,
	100%,
	40% {
		transform: scaleY(.4);
		-webkit-transform: scaleY(.4)
	}

	20% {
		transform: scaleY(1);
		-webkit-transform: scaleY(1)
	}
}
