sr7-prl.prlt3 {
	margin: -9px 0px 0px -35px;
	width: 70px;
	text-align: center;
}

sr7-prl.prlt3 .bounce1,
sr7-prl.prlt3 .bounce2,
sr7-prl.prlt3 .bounce3 {
	width: 18px;
	height: 18px;
	background-color: #fff;
	box-shadow: 0px 0px 20px 0px rgba(0,0,0,0.15);
	border-radius: 100%;
	display: inline-block;
	animation: tp-bouncedelay 1.4s infinite ease-in-out;
	/* Prevent first frame from flickering when animation starts */
	animation-fill-mode: both;
}

sr7-prl.prlt3 .bounce1 {
	animation-delay: -0.32s;
}

sr7-prl.prlt3 .bounce2 {
	animation-delay: -0.16s;
}

@keyframes tp-bouncedelay {
	0%, 80%, 100% {transform: scale(0.0);}
	40% {transform: scale(1.0);}
  }